# Shortgenius

Types:

```python
from shortgenius.types import HealthCheckResponse
```

Methods:

- <code title="get /health">client.<a href="./src/shortgenius/_client.py">health_check</a>() -> <a href="./src/shortgenius/types/health_check_response.py">HealthCheckResponse</a></code>
